@@ -3,6 +3,7 @@
 #' Add beautiful interactive bubbles within Shing and RMarkdown backgrounds
 #'
 #' @param theme Name of the bubbles theme. See the vignette for a list of themes.
+#' @param color Text color. Defaults to 'white'
 #'
 #' @return Themed interactive bubbles for Shiny and RMarkdown backgrounds
 #' @export
@@ -32,7 +33,7 @@
 #'
 
 
-bubbly <- function(theme = "ocean") {
+bubbly <- function(theme = "ocean", color = "white") {
   if (!theme %in% c(
     "ocean",
     "cherry",
@@ -55,7 +56,8 @@ bubbly <- function(theme = "ocean") {
     "gravitas",
     "rladies",
     "sunshine",
-    "sweet"
+    "sweet",
+    "lalaland"
 
   )) {
     stop(paste0(theme, " theme is not available, did you misspelled the theme ?"))
@@ -66,6 +68,8 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
       htmltools::tags$script(htmltools::HTML("bubbly();"))
 
 
@@ -76,6 +80,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "bubbly({colorStart: '#111',colorStop: '#422',bubbleFunc: () => `hsla(0, 100%, 50%, ${Math.random() * 0.25})`});"
@@ -93,6 +100,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "bubbly({colorStart: '#4c004c',colorStop: '#1a001a',bubbleFunc: () => `hsla(${Math.random() * 360}, 100%, 50%, ${Math.random() * 0.25})`});"
@@ -111,6 +121,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "bubbly({colorStart: '#fff4e6', colorStop: '#ffe9e4', blur: 1, compose: 'source-over', bubbleFunc: () => `hsla(${Math.random() * 50}, 100%, 50%, .3)`});"
@@ -128,6 +141,8 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
       htmltools::tags$script(
         htmltools::HTML(
           "bubbly({blur:15, colorStart: '#194167', colorStop: '#112144', radiusFunc:() => 5 + Math.random() * 15, angleFunc:() => -Math.PI / 2, velocityFunc:() => Math.random() * 1.5, bubbleFunc:() => `hsla(${200 + Math.random() * 50}, 100%, 65%, .1)`,bubbles:350});"
@@ -145,6 +160,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -182,6 +200,8 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -222,6 +242,8 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -260,6 +282,8 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -301,6 +325,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -341,6 +368,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -376,6 +406,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -414,6 +447,8 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -449,6 +484,8 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -488,6 +525,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -521,6 +561,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -554,6 +597,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -586,6 +632,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -621,6 +670,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -655,6 +707,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -692,6 +747,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -724,6 +782,9 @@ bubbly <- function(theme = "ocean") {
     htmltools::tagList(
       htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
 
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
       htmltools::tags$script(
         htmltools::HTML(
           "
@@ -759,6 +820,42 @@ bubbly <- function(theme = "ocean") {
 
 
 
+  } else if (theme == "lalaland"){
+
+    htmltools::tagList(
+
+      htmltools::tags$script(src = "https://cdn.jsdelivr.net/npm/bubbly-bg@1.0.0/dist/bubbly-bg.js"),
+
+      htmltools::tags$style(htmltools::HTML(glue::glue("body{{color:{color}}}"))),
+
+
+      htmltools::tags$script(
+        htmltools::HTML(
+          "
+  bubbly({
+  colorStart: '#0A0C12',
+  colorStop: '#0B0E15',
+  bubbles:100,
+  blur:0,
+  compose: 'source-over',
+  bubbleFunc:() => `hsla(${0 + Math.random() * 10}, 100%, 100%, 1)`,
+  velocityFunc:() => 0.05 + Math.random() * 0.05,
+  radiusFunc:() => Math.random() * 1.2
+    });
+
+
+      "
+
+
+
+
+        )
+      )
+
+
+    )
+
+
   }
 
 
